@@ -1,6 +1,6 @@
 ############################################################
 #
-#   $Id: Filesystem.pm 61 2010-02-12 14:36:11Z trevor $
+#   $Id: Filesystem.pm 68 2010-02-19 12:58:40Z trevor $
 #   Sys::Filesystem - Retrieve list of filesystems and their properties
 #
 #   Copyright 2004,2005,2006 Nicola Worthington
@@ -42,9 +42,10 @@ use Params::Util qw(_INSTANCE);
 use Scalar::Util qw(blessed);
 
 use constant DEBUG => $ENV{SYS_FILESYSTEM_DEBUG} ? 1 : 0;
-use constant SPECIAL => ( 'darwin' eq $^O ) ? 0 : undef;
+#use constant SPECIAL => ( 'darwin' eq $^O ) ? 0 : undef;
+use constant SPECIAL => undef;
 
-$VERSION = '1.26';
+$VERSION = '1.27';
 
 my ( $FsPlugin, $Supported );
 
@@ -334,7 +335,7 @@ ignored on some systems.
 
 Specify the full path and filename of the mounted NFS filesystem table
 (or xtab for short). This is usually only pertinant to Unix bases systems.
-Not all helper modules will query NFS mounts as a seperate exercise, and
+Not all helper modules will query NFS mounts as a separate exercise, and
 therefore this option may be ignored on some systems.
 
 =back
@@ -484,12 +485,12 @@ Returns the order in which this filesystem should be mounted on boot.
 
 =item check_order()
 
-Returns the order in which this filesystem should be consistancy checked
+Returns the order in which this filesystem should be consistency checked
 on boot.
 
 =item check_frequency()
 
-Returns how often this filesystem is checked for consistancy.
+Returns how often this filesystem is checked for consistency.
 
 =back
 
@@ -499,7 +500,7 @@ Returns how often this filesystem is checked for consistancy.
 
 The Dummy module is there to provide a default failover result to the main
 Sys::Filesystem module if no suitable platform specific module can be found
-or sucessfully loaded. This is the last module to be tried, in order of
+or successfully loaded. This is the last module to be tried, in order of
 platform, Unix (if not on Win32), and then Dummy.
 
 =head2 Unix
@@ -552,7 +553,7 @@ L<perlport>, L<Solaris::DeviceTree>, L<Win32::DriveInfo>
 
 =head1 VERSION
 
-$Id: Filesystem.pm 61 2010-02-12 14:36:11Z trevor $
+$Id: Filesystem.pm 68 2010-02-19 12:58:40Z trevor $
 
 =head1 AUTHOR
 
